==> haskell-distributive-0.6.2.1-410.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
key:                  distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  c6df816cedee687b7085323762d22e1f
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6.2.1-413-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 distributive
version:              0.6.2.1
visibility:           public
id:                   distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
key:                  distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
license:              BSD-3-Clause
copyright:            Copyright (C) 2011-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/distributive/
synopsis:             Distributive functors -- Dual to Traversable
description:          Distributive functors -- Dual to @Traversable@
category:             Data Structures
abi:                  765f25c3a509aa0aca92445669a60a4f
exposed:              True
exposed-modules:      Data.Distributive Data.Distributive.Generic
import-dirs:          /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/distributive-0.6.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-distributive
hs-libraries:         HSdistributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-distributive/html/distributive.haddock

haddock-html:         /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
